;; Debian adjustments for project.clj

(require '[debian.dh-clojure-lein.client :as deb])

(defn dh-clj-adjust-project [project when & _]
  "Drop clojurescript plugin and dependency."
  (case when
    :before-plugins
    (update (project) :plugins deb/del-dep 'lein-cljsbuild)
    :after-middleware
    (-> (project)
        (dissoc :parent)
        (assoc :source-paths ["src/main/clojure"])
        (update :dependencies deb/del-dep 'org.clojure/clojurescript))
    (project)))
